@@ -303,7 +303,15 @@ sub databases
 	## There should not be a live user and database just to check what databases there are.
 	if( !$self->{dbh} )
 	{
-		$dbh = $self->connect || return( undef() );
+		try
+		{
+			$dbh = $self->connect || return( undef() );
+		}
+		catch( $e )
+		{
+			$self->message( 3, "An error occurred while trying to connect to get the list of available databases: $e" );
+			return;
+		}
 	}
 	else
 	{
@@ -1343,8 +1351,8 @@ DB::Object::Postgres - SQL API
 
 =head1 DESCRIPTION
 
-C<DB::Object::Postgres> is a SQL API much alike C<DBD::Pg>.
-So why use a private module instead of using that great C<DBD::Pg> package?
+L<DB::Object::Postgres> is a SQL API much alike L<DBD::Pg>.
+So why use a private module instead of using that great L<DBD::Pg> package?
 
 At first, I started to inherit from C<DBI> to conform to C<perlmod> perl 
 manual page and to general perl coding guidlines. It became very quickly a 
@@ -1352,7 +1360,7 @@ real hassle. Barely impossible to inherit, difficulty to handle error, too
 much dependent from an API that change its behaviour with new versions.
 In short, I wanted a better, more accurate control over the SQL connection.
 
-So, C<DB::Object::Postgres> acts as a convenient, modifiable wrapper that provide the
+So, L<DB::Object::Postgres> acts as a convenient, modifiable wrapper that provide the
 programmer with an intuitive, user-friendly and hassle free interface.
 
 =head1 CONSTRUCTOR
@@ -1361,11 +1369,11 @@ programmer with an intuitive, user-friendly and hassle free interface.
 
 =item B<new>()
 
-Create a new instance of C<DB::Object::Postgres>. Nothing much to say.
+Create a new instance of L<DB::Object::Postgres>. Nothing much to say.
 
 =item B<connect>( DATABASE, LOGIN, PASSWORD, SERVER, DRIVER )
 
-Create a new instance of C<DB::Object::Postgres>, but also attempts a conection
+Create a new instance of L<DB::Object::Postgres>, but also attempts a conection
 to SQL server.
 You can specify the following arguments:
 
